@@ -251,7 +251,7 @@ class DrbHttpNode(AbstractNode):
         self._auth = auth
         self._params = params
         self._children = []
-        self._available_impl.append(io.BytesIO)
+        self.add_impl(io.BytesIO, _to_stream)
 
     def __init_header(self):
         if len(self._attrs) == 0:
@@ -279,18 +279,17 @@ class DrbHttpNode(AbstractNode):
 
     @property
     def auth(self) -> AuthBase:
-        if self._auth is not None:
-            if isinstance(self._auth, HTTPBasicAuth):
-                credential = keyring.get_credential(
-                    self.path.path,
-                    self._auth.username
+        if self._auth is None:
+            credential = keyring.get_credential(
+                service_name=self.path.path,
+                username=None
+            )
+            if credential is not None:
+                self._auth = HTTPBasicAuth(
+                    credential.username,
+                    credential.password
                 )
-                if credential is not None:
-                    return HTTPBasicAuth(
-                        credential.username,
-                        credential.password
-                    )
-            return self._auth
+        return self._auth
 
     def __setitem__(self, key, value):
         raise NotImplementedError
@@ -334,43 +333,6 @@ class DrbHttpNode(AbstractNode):
         raise DrbException(f'Attribute not found name: {name}, '
                            f'namespace: {namespace_uri}')
 
-    def get_impl(self, impl: type, **kwargs) -> Any:
-        """
-          This operation returns a reference to an object implementing a
-          specific interface. This method authorizes a specific and/or direct
-          API instead of using the DrbNode interface. The provided object is
-          independent of this node and shall be released/closed by the caller
-          when interface requires such finally operations.
-
-          Parameters:
-              impl (type): the implementation type expected
-
-          Keyword Arguments:
-              start (int): The first byte to be downloaded.
-              end (int): The last byte to be downloaded.
-
-          Return:
-              Any: the expected implementation.
-          Raises:
-              DrbNotImplementedException: if `impl` is not supported by the
-                                          current node
-        """
-        if self.has_impl(impl):
-            headers = None
-            if 'start' in kwargs:
-                if 'end' in kwargs:
-                    headers = (kwargs.get('start'), kwargs.get('end'))
-                else:
-                    headers = (kwargs.get('start'),)
-            return Download(self.path.name,
-                            self.auth,
-                            self.params,
-                            headers,
-                            kwargs.get('chunk_size', 4 * 1048576)
-                            )
-        raise DrbNotImplementationException(
-            f'no {impl} implementation found')
-
     @staticmethod
     def post(url: str,
              headers: dict = None,
@@ -394,8 +356,16 @@ class DrbHttpNode(AbstractNode):
                                  auth=auth)
         return DrbHttpResponse(path=url, response=response)
 
-    def close(self) -> None:
-        pass
+
+def _to_stream(node: DrbHttpNode, **kwargs):
+    headers = None
+    if 'start' in kwargs:
+        if 'end' in kwargs:
+            headers = (kwargs.get('start'), kwargs.get('end'))
+        else:
+            headers = (kwargs.get('start'),)
+    return Download(node.path.name, node.auth, node.params, headers,
+                    kwargs.get('chunk_size', 4 * 1048576))
 
 
 class DrbHttpResponse(DrbHttpNode):
@@ -407,10 +377,6 @@ class DrbHttpResponse(DrbHttpNode):
             (k, None): v for k, v in self._resp.headers.items()
         }
         self.value = response.content
-        self._available_impl.append(io.BytesIO)
-
-    def get_impl(self, impl: type, **kwargs) -> Any:
-        return io.BytesIO(self._resp.content)
 
 
 class DrbHttpFactory(DrbFactory):
