@@ -4,7 +4,6 @@ from unittest.mock import patch
 from multiprocessing import Process
 
 from keyring.credentials import SimpleCredential
-from requests.auth import HTTPBasicAuth
 
 from drb.drivers.http import DrbHttpNode
 from tests.utility import start_auth_serve, PORT, PATH
@@ -12,7 +11,7 @@ from tests.utility import start_auth_serve, PORT, PATH
 process = Process(target=start_auth_serve)
 
 
-def my_credential(usr, pwd):
+def my_credential(service_name, username):
     return SimpleCredential('user', 'pwd123456')
 
 
@@ -29,7 +28,7 @@ class TestBitwardenKeyring(unittest.TestCase):
 
     @patch(target="keyring.get_credential", new=my_credential)
     def test_keyring_auth(self):
-        node = DrbHttpNode(path=self.url_ok, auth=HTTPBasicAuth('usr', 'pwd'))
+        node = DrbHttpNode(path=self.url_ok)
 
         self.assertEqual('{"path": "/resources/test.txt"}',
                          node.get_impl(io.BytesIO).getvalue().decode())
